------------------------------------------------------------------------
--      XCRPDEMO.VHD -- Digilab XCRP Test Configuration
------------------------------------------------------------------------
-- Author:  Clint Cole
--          Copyright 2002 Digilent, Inc.
------------------------------------------------------------------------
-- This module is a test circuit to test the Digilab XCR Plus board.
--
--  Inputs:
--		mclk		- system clock
--		btn		- buttons on the XCRP board (4 buttons)
--		swt		- switches on the XCRP board (8 switches)
--
--  Outputs:
--		led		- discrete LEDs on the XCRP board (8 leds)
--		an			- anode lines for the 7-seg displays on XCRP
--		ssg		- cathodes (segment lines) for the displays on XCRP
--
------------------------------------------------------------------------
-- Revision History:
--  09/04/2002(ClintC): created
------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity xcrpdemo is
    Port ( mclk : in std_logic;
		   btn : in std_logic_vector(3 downto 0);
		   swt : in std_logic_vector(7 downto 0);
		   led : out std_logic_vector(7 downto 0);
		   an  : out std_logic_vector(1 downto 0);
		   ssg : out std_logic_vector(6 downto 0));
end xcrpdemo;

architecture Behavioral of xcrpdemo is

	------------------------------------------------------------------------
 	-- Component Declarations
	------------------------------------------------------------------------

    component ssg_driver is
    Port ( mclk : in  STD_LOGIC;
           sum : in  STD_LOGIC_VECTOR (3 downto 0);
			  overflow : in std_logic;
           an : out  STD_LOGIC_VECTOR (1 downto 0);
           ssg : out  STD_LOGIC_VECTOR (6 downto 0));
    end component;

    component simple_alu is
    port( a,b : in std_logic_vector(3 downto 0);
          sub : in std_logic;
          sum : out std_logic_vector(3 downto 0);
          overflow : out std_logic);
    end component;


	------------------------------------------------------------------------
	-- Signal Declarations
	------------------------------------------------------------------------
   
	signal sum  : std_logic_vector(3 downto 0);
   signal s    : std_logic_vector(3 downto 0);
	signal a    : std_logic_vector(3 downto 0);
   signal b    : std_logic_vector(3 downto 0);
   signal sub  : std_logic;
   signal ce_a : std_logic;
   signal sel : std_logic_vector(1 downto 0);
	signal overflow : std_logic;
	
	------------------------------------------------------------------------
	-- Module Implementation
	------------------------------------------------------------------------

begin

	-- Connect slide switches to LEDs

	led(3 downto 0) <= a(0) & a(1) & a(2) & a(3); -- reverse bits
   led(7 downto 4) <= b(0) & b(1) & b(2) & b(3); -- reverse bits
	b <= swt(0) & swt(1) & swt(2) & swt(3);
	ce_a <= swt(4);
	sel <= swt(7 downto 6); -- select alu ops
	sub <= swt(5);	-- not(add)/sub signal

   -- register with clock enable
	process(mclk, ce_a)
	begin
     if (mclk = '1' and mclk'Event) then
        if (ce_a = '1') then
		    a <= swt(0) & swt(1) & swt(2) & swt(3);
	     end if;
     end if;
   end process;

   ssg_drive : ssg_driver 
	  port map(
	    mclk => mclk,
		 sum => sum,
		 overflow => overflow,
		 an => an,
		 ssg => ssg);
		 

   -- put simple_alu here           

end Behavioral;
